==> haskell-http-client-restricted-0.1.0-163-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-http-client-restricted.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 http-client-restricted
version:              0.1.0
visibility:           public
id:                   http-client-restricted-0.1.0-19Xu0rh0vlMKl7ffAKyeYJ
key:                  http-client-restricted-0.1.0-19Xu0rh0vlMKl7ffAKyeYJ
license:              MIT
copyright:            2018 Joey Hess, 2013 Michael Snoyman
maintainer:           Joey Hess <id@joeyh.name>
author:               Joey Hess
synopsis:             restricting the servers that http-client will use
description:
    Addition to the http-client and http-client-tls
    libraries, that restricts the HTTP servers that can be used.

    This is useful when a security policy needs to eg, prevent connections to
    HTTP servers on localhost or a local network, or only allow connections
    to a specific HTTP server.

    It handles restricting redirects as well as the initial HTTP connection,
    and it also guards against DNS poisoning attacks.

category:             Network
abi:                  6888abafc8f1fb831efdd7f6b724c0d3
exposed:              True
exposed-modules:      Network.HTTP.Client.Restricted
import-dirs:          /usr/lib/ghc-9.4.8/site-local/http-client-restricted-0.1.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/http-client-restricted-0.1.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/http-client-restricted-0.1.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-http-client-restricted
hs-libraries:         HShttp-client-restricted-0.1.0-19Xu0rh0vlMKl7ffAKyeYJ
depends:
    base-4.17.2.1 crypton-connection-0.4.4-Euem0yM0Cv6LMDpPbuhAEm
    data-default-0.7.1.2-7bG7braRZax6ZJaJ3dSesR
    http-client-0.7.19-LiXl0zXhncYKUDAcqgcwk8
    http-client-tls-0.3.6.4-8Rtb2QgRnuG7Z2EdKrVOdn
    network-3.1.4.0-BMQQjwbPvFR57Ka0tgIiy2
    network-bsd-2.8.1.0-FFpbVO9AuzE8JLFVOXvOKf
    utf8-string-1.0.2-D0oARDqSiCF3CIA0pPBIDm

haddock-interfaces:
    /usr/share/doc/haskell-http-client-restricted/html/http-client-restricted.haddock

haddock-html:         /usr/share/doc/haskell-http-client-restricted/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-http-client-restricted-0.1.0-185-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-http-client-restricted.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 http-client-restricted
version:              0.1.0
visibility:           public
id:                   http-client-restricted-0.1.0-I5DZivETdy13tv2fIeDZyg
key:                  http-client-restricted-0.1.0-I5DZivETdy13tv2fIeDZyg
license:              MIT
copyright:            2018 Joey Hess, 2013 Michael Snoyman
maintainer:           Joey Hess <id@joeyh.name>
author:               Joey Hess
synopsis:             restricting the servers that http-client will use
description:
    Addition to the http-client and http-client-tls
    libraries, that restricts the HTTP servers that can be used.

    This is useful when a security policy needs to eg, prevent connections to
    HTTP servers on localhost or a local network, or only allow connections
    to a specific HTTP server.

    It handles restricting redirects as well as the initial HTTP connection,
    and it also guards against DNS poisoning attacks.

category:             Network
abi:                  3aa1b729d4b16831405fdf2d99a5392e
exposed:              True
exposed-modules:      Network.HTTP.Client.Restricted
import-dirs:          /usr/lib/ghc-9.4.8/site-local/http-client-restricted-0.1.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/http-client-restricted-0.1.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/http-client-restricted-0.1.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-http-client-restricted
hs-libraries:         HShttp-client-restricted-0.1.0-I5DZivETdy13tv2fIeDZyg
depends:
    base-4.17.2.1 crypton-connection-0.4.5-CBwSG29ckAMGaPodtkho7w
    data-default-0.7.1.3-1SaGr9SWFYZ17MG1fTAOKi
    http-client-0.7.19-Iyp8kyAVyHs5ic3dfNFLTs
    http-client-tls-0.3.6.4-Fuw6mDzbeZhIZH9nOSD8AM
    network-3.1.4.0-2g2oEkgQCahBaM3HvlpVNW
    network-bsd-2.8.1.0-45NgNz6r2kWHrH0TdvR5cZ
    utf8-string-1.0.2-D0oARDqSiCF3CIA0pPBIDm

haddock-interfaces:
    /usr/share/doc/haskell-http-client-restricted/html/http-client-restricted.haddock

haddock-html:         /usr/share/doc/haskell-http-client-restricted/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
